/* state.js v0.5.0 | MIT | /http://code.negative9.net/geoff/state.js */
(function(root, factory) {
    /* eslint-disable */
    if (typeof define === 'function' && define.amd) {
        // AMD
        define(['state'], factory);
    } else if(typeof module === 'object' && module.exports) {
        // CommonJS / NodeJS
        module.exports = factory(root.state);
    } else {
        // Global
        root.state = factory(root.state);
    }

}(this, function() {
    'use strict';

    function state(opts) {
        opts = Object.assign({cache: false, debug: false}, opts || {});

        let _state = {};

        _log('INIT:', _state);
        _log('DEBUG:', opts.debug);
        _log('CACHE:', opts.cache);

        function _log(...msg) {
            if(opts.debug) {
                /* eslint-disable */
                console.log(msg);
            }
        }

        function _has(val) {
            if(typeof val !== 'object' || val === null) {
                return !!val ? val : false;
            } else {

                if(typeof val === "object") {

                    if(val.length !== 'undefined') {
                        return !!val.length ? val : false;
                    } else {

                        return (Object.getOwnPropertyNames(val).length > 0) ? val : false;
                    }
                }
            }
        }

        return {
            get: (key) => {
                if(opts.cache) {
                    return _has(JSON.parse(global.localStorage.getItem(key)));
                } else {
                    return _state[key];
                }
            },
            set: (key, value) => {
                if(opts.cache) {
                    global.localStorage.setItem(key, JSON.stringify(value));
                } else {
                    _state[key] = value;
                }

                return value;
            },
            remove: (key) => {
                if(opts.cache) {
                    return global.localStorage.removeItem(key);
                } else {
                    return _state[key] = null;
                }
            },
            clear: () => {}
        }

    };

    // Return it
    return state;
}));
